@@ -31,12 +31,12 @@ class NBApi(FastAPI):
 
         async def http_middleware(request: Request, call_next):
             ts = time.time()
-            request.state.set(KEY_ID, str(uuid.uuid4()))
-            request.state.set(KEY_CID, 'unknown')
-            request.state.set(KEY_AUTH, request.headers['authorization'])
+            setattr(request.state, KEY_ID, str(uuid.uuid4()))
+            setattr(request.state, KEY_CID, 'unknown')
+            setattr(request.state, KEY_AUTH, request.headers['authorization'])
             resp = await call_next(request)
-            c.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.get(KEY_CID)).inc()
-            g.labels(path=request.url.path, status_code=resp.status_code, cid=request.state.get(KEY_CID)).set(time.time() - ts)
+            c.labels(path=request.url.path, status_code=resp.status_code, cid=getattr(request.state, KEY_CID)).inc()
+            g.labels(path=request.url.path, status_code=resp.status_code, cid=getattr(request.state, KEY_CID)).set(time.time() - ts)
             return resp
 
         self.middleware('http')(http_middleware)
